@@ -261,6 +261,10 @@ if(isset($_GET['action'])){
                 die("Error while deleting: no Bibtex ID selected!");
             }  
             else{
+                // check we have the authorization to delete
+                if(!array_key_exists('user_can_delete',$_SESSION) || !$_SESSION['user_can_delete']){
+                    die("You are not authorized to delete references!");
+                }
                 $confirm = FALSE;
                 if(array_key_exists('confirm_delete',$_GET)){
                     $confirm = (strcmp($_GET['confirm_delete'],msg("Yes")) == 0);
@@ -303,10 +307,10 @@ if(isset($_GET['action'])){
 	
         case 'add':					// Add entries in the basket to a given group
             if(isset($_GET['groupvalue'])){
-                $gval = trim($_GET['groupvalue']);
+                $gval = htmlentities(trim($_GET['groupvalue']));
             }
             if(isset($_GET['newgroupvalue'])){
-                $gval = trim($_GET['newgroupvalue']);
+                $gval = htmlentities(trim($_GET['newgroupvalue']));
             }
             if(!isset($gval)){
                 die(msg("No group specified!"));
@@ -329,26 +333,40 @@ if(isset($_GET['action'])){
             break;
 	
         case 'update_type':
-            $_SESSION['bibdb']->change_type($_GET['id'],$_GET['bibtex_type']);
+            // check we have the authorization to modify
+            if(!array_key_exists('user_can_modify',$_SESSION) || !$_SESSION['user_can_modify']){
+                die("You are not authorized to modify references!");
+            }
+            $_SESSION['bibdb']->change_type(htmlentities($_GET['id']),htmlentities($_GET['bibtex_type']));
             $_GET['mode']='update';
             break;
             
         case 'update_key': // update the BibTeX key of a reference
-            if(!$_SESSION['bibdb']->is_bibtex_key_present($_GET['bibtex_key'])){
-                $_SESSION['bibdb']->change_id($_GET['id'],$_GET['bibtex_key']);
-                $_GET['mode']='update';
-                $_GET['id'] = $_GET['bibtex_key'];
+        // check we have the authorization to modify
+            if(!array_key_exists('user_can_modify',$_SESSION) || !$_SESSION['user_can_modify']){
+                die("You are not authorized to modify references!");
+            }
+            $oldid = htmlentities($_GET['id']);
+            $newid = htmlentities($_GET['bibtex_key']);
+            if(!$_SESSION['bibdb']->is_bibtex_key_present($newid)){
+                $_SESSION['bibdb']->change_id($oldid,$newid);
+                $_GET['mode'] = 'update';
+                $_GET['id'] = $newid;
                 // change the value in the basket
-                $_SESSION['basket']->remove_item($_GET['id']);
-                $_SESSION['basket']->add_item($_GET['bibtex_key']);
+                $_SESSION['basket']->remove_item($oldid);
+                $_SESSION['basket']->add_item($newid);
             }
             else{
-                $error = sprintf(msg("BibTeX key <code>%s</code> already exists."),$_GET['bibtex_key']);
+                $error = sprintf(msg("BibTeX key <code>%s</code> already exists."),$newid);
                 $_GET['mode'] = 'operationresult';
             }
             break;
 
         case 'delete_basket':
+            // check we have the authorization to delete
+            if(!array_key_exists('user_can_delete',$_SESSION) || !$_SESSION['user_can_delete']){
+                die("You are not authorized to delete references!");
+            }
             $confirm = FALSE;
             if(array_key_exists('confirm_delete',$_GET)){
                 $confirm = (strcmp($_GET['confirm_delete'],msg("Yes"))==0);
@@ -396,6 +414,10 @@ if(isset($_POST['action'])){
             Add an entry to the database
         */
         case 'add_entry': 
+            // check we have the authorization to modify
+            if(!array_key_exists('user_can_add',$_SESSION) || !$_SESSION['user_can_add']){
+                die("You are not authorized to add references!");
+            }
             if(isset($_POST['ok'])){
                 $res = $_SESSION['bibdb']->add_new_entry($_POST);
                 if($res['added']){
@@ -419,6 +441,10 @@ if(isset($_POST['action'])){
     
         // update an entry
         case 'update_entry':
+                // check we have the authorization to modify
+                if(!array_key_exists('user_can_modify',$_SESSION) || !$_SESSION['user_can_modify']){
+                    die("You are not authorized to modify references!");
+                }
             if(isset($_POST['ok'])){
                 $res = $_SESSION['bibdb']->update_entry($_POST);
                 if($res['updated']){
@@ -444,6 +470,10 @@ if(isset($_POST['action'])){
             Import bibtex entries.
         */
         case 'import':
+            // check we have the authorization to modify
+            if(!array_key_exists('user_can_add',$_SESSION) || !$_SESSION['user_can_add']){
+                die("You are not authorized to add references!");
+            }
             if(!array_key_exists('bibfile',$_FILES) && !array_key_exists('bibval',$_POST)){
                 die("Error, no bibtex data provided!");
             }
