@@ -97,7 +97,7 @@ class Auth
         }
         else{
             // Get ($user,$pass) record
-            $query = "SELECT login,password FROM ".$this->users_table." WHERE login='".addslashes($user)."' AND password=md5('".addslashes($pass)."')";
+            $query = "SELECT login,password FROM ".$this->users_table." WHERE login='".mysql_real_escape_string($user)."' AND password=md5('".mysql_real_escape_string($pass)."')";
             $result = mysql_query($query,$connect) or die("Invalid SQL Request");
             return (mysql_num_rows($result)>0);
         }
@@ -116,7 +116,7 @@ class Auth
         }
         else{
             // get $admin value for $user
-            $query = "SELECT admin FROM ".$this->users_table." WHERE login='".addslashes($user)."'";
+            $query = "SELECT admin FROM ".$this->users_table." WHERE login='".mysql_real_escape_string($user)."'";
             $result = mysql_query($query,$connect) or die("Invalid SQL request.");
             
             if(mysql_num_rows($result) != 0){
@@ -143,7 +143,7 @@ class Auth
         else{
             $user = ($user == "" ? "_anonymous_" : $user);
             // get records where $id = $user
-            $query = "SELECT id FROM ".$this->users_table." WHERE login='".addslashes($user)."'";
+            $query = "SELECT id FROM ".$this->users_table." WHERE login='".mysql_real_escape_string($user)."'";
             $result = mysql_query($query,$connect) or die("Invalid SQL request.");
             
             if(mysql_num_rows($result) != 0){
@@ -159,7 +159,7 @@ class Auth
                     return $access[2] == '1';
                 }
                 else{
-                    $query = "SELECT access FROM ".$this->users_auth." WHERE user_id='$id' AND db_name='".addslashes($database_name)."'";
+                    $query = "SELECT access FROM ".$this->users_auth." WHERE user_id='$id' AND db_name='".mysql_real_escape_string($database_name)."'";
                     $result = mysql_query($query,$connect) or die("Invalid SQL request.");
                     $row = mysql_fetch_assoc($result);
                     $access = $row['access'];
@@ -185,7 +185,7 @@ class Auth
         else{
             $user = ($user == "" ? "_anonymous_" : $user);
             
-            $query = "SELECT id FROM ".$this->users_table." WHERE login='".addslashes($user)."'";
+            $query = "SELECT id FROM ".$this->users_table." WHERE login='".mysql_real_escape_string($user)."'";
             $result = mysql_query($query,$connect) or die("Invalid SQL request.");
             
             if(mysql_num_rows($result) != 0){
@@ -201,7 +201,7 @@ class Auth
                     return $access[0] == '1';
                 }
                 else{
-                    $query = "SELECT access FROM ".$this->users_auth." WHERE user_id='$id' AND db_name='".addslashes($database_name)."'";
+                    $query = "SELECT access FROM ".$this->users_auth." WHERE user_id='$id' AND db_name='".mysql_real_escape_string($database_name)."'";
                     $result = mysql_query($query,$connect) or die("Invalid SQL request.");
                     $row = mysql_fetch_assoc($result);
                     $access = $row['access'];
@@ -227,7 +227,7 @@ class Auth
         else{
             $user = ($user == "" ? "_anonymous_" : $user);
             
-            $query = "SELECT id FROM ".$this->users_table." WHERE login='".addslashes($user)."'";
+            $query = "SELECT id FROM ".$this->users_table." WHERE login='".mysql_real_escape_string($user)."'";
             $result = mysql_query($query,$connect) or die("Invalid SQL request.");
             
             if(mysql_num_rows($result) != 0){
@@ -243,7 +243,7 @@ class Auth
                     return $access[1] == '1';
                 }
                 else{
-                    $query = "SELECT access FROM ".$this->users_auth." WHERE user_id='$id' AND db_name='".addslashes($database_name)."'";
+                    $query = "SELECT access FROM ".$this->users_auth." WHERE user_id='$id' AND db_name='".mysql_real_escape_string($database_name)."'";
                     $result = mysql_query($query,$connect) or die("Invalid SQL request.");
                     $row = mysql_fetch_assoc($result);
                     $access = $row['access'];
