@@ -275,15 +275,15 @@ class BibORB_DataBase {
         }
         else{
             // upload files if they are present
-            if(array_key_exists('url',$_FILES) && file_exists($_FILES['url']['tmp_name'])){
+            if(array_key_exists('url',$_FILES) && file_exists($_FILES['url']['tmp_name']) && !ereg("(.php|.html|.htm)$",$_FILES['url']['name'])){
                 $urlfile=upload_file($this->biblio_name,'url',$dataArray['id']);
                 $dataArray['url'] = $urlfile;
             }
-            if(array_key_exists('urlzip',$_FILES) && file_exists($_FILES['urlzip']['tmp_name'])){
+            if(array_key_exists('urlzip',$_FILES) && file_exists($_FILES['urlzip']['tmp_name']) && !ereg("(.php|.html|.htm)$",$_FILES['urlzip']['name'])){
                 $urlzipfile=upload_file($this->biblio_name,'urlzip',$dataArray['id']);
                 $dataArray['urlzip'] = $urlzipfile;
             }  
-            if(array_key_exists('pdf',$_FILES) && file_exists($_FILES['pdf']['tmp_name'])){
+            if(array_key_exists('pdf',$_FILES) && file_exists($_FILES['pdf']['tmp_name']) && !ereg("(.php|.html|.htm)$",$_FILES['pdf']['name'])){
                 $pdffile=upload_file($this->biblio_name,'pdf',$dataArray['id']);
                 $dataArray['pdf'] = $pdffile;
             }
@@ -394,7 +394,7 @@ class BibORB_DataBase {
             $urlzipfile = null;
             $pdffile = null;
             
-            if(array_key_exists('url',$_FILES) && file_exists($_FILES['url']['tmp_name'])){
+            if(array_key_exists('url',$_FILES) && file_exists($_FILES['url']['tmp_name'])&& !ereg("(.php|.html|.htm)$",$_FILES['url']['name'])){
                 $urlfile = upload_file($this->biblio_name,'url',$dataArray['id']);
                 $dataArray['url'] = $urlfile;
             }
@@ -403,7 +403,7 @@ class BibORB_DataBase {
                 $dataArray['url'] = $urlfile;
             }
             
-            if(array_key_exists('urlzip',$_FILES) && file_exists($_FILES['urlzip']['tmp_name'])){
+            if(array_key_exists('urlzip',$_FILES) && file_exists($_FILES['urlzip']['tmp_name']) && !ereg("(.php|.html|.htm)$",$_FILES['urlzip']['name'])){
                 $urlzipfile = upload_file($this->biblio_name,'urlzip',$dataArray['id']);
                 $dataArray['urlzip'] = $urlzipfile;
             }
@@ -412,7 +412,7 @@ class BibORB_DataBase {
                 $dataArray['urlzip'] = $urlzipfile;
             }  
             
-            if(array_key_exists('pdf',$_FILES) && file_exists($_FILES['pdf']['tmp_name'])){
+            if(array_key_exists('pdf',$_FILES) && file_exists($_FILES['pdf']['tmp_name']) && !ereg("(.php|.html|.htm)$",$_FILES['pdf']['name'])){
                 $pdffile = upload_file($this->biblio_name,'pdf',$dataArray['id']);
                 $dataArray['pdf'] = $pdffile;
             }
